import { type NextRequest, NextResponse } from "next/server"
import { getContent, updateContent } from "../../../utils/content-manager"
import { getAuthToken, verifyAuth } from "../../../utils/auth"

export async function GET() {
  try {
    const content = await getContent()
    return NextResponse.json(content)
  } catch (error) {
    console.error("Error in GET /api/content:", error)
    return NextResponse.json({ error: "Failed to fetch content" }, { status: 500 })
  }
}

export async function PUT(request: NextRequest) {
  try {
    const token = getAuthToken()

    if (!token) {
      return NextResponse.json({ success: false, error: "Authentication required" }, { status: 401 })
    }

    const authResult = await verifyAuth(token)

    if (!authResult.success) {
      return NextResponse.json({ success: false, error: "Invalid authentication" }, { status: 401 })
    }

    const { section, data } = await request.json()
    const result = await updateContent(section, data)

    if (result.success) {
      return NextResponse.json({ success: true })
    } else {
      return NextResponse.json({ success: false, error: result.error }, { status: 500 })
    }
  } catch (error) {
    console.error("Error in PUT /api/content:", error)
    return NextResponse.json({ success: false, error: "Internal server error" }, { status: 500 })
  }
}

